<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\CronJob;
use App\Lib\CurlRequest;
use App\Models\TradeLog;
use App\Constants\Status;
use App\Models\CronJobLog;
use App\Models\PracticeLog;
use App\Models\Transaction;
use App\Models\CryptoCurrency;
use Exception;

class CronController extends Controller
{
    public function cron()
    {
        $general            = gs();
        $general->last_cron = now();
        $general->save();

        $crons = CronJob::with('schedule');

        if (request()->alias) {
            $crons->where('alias', request()->alias);
        } else {
            $crons->where('next_run', '<', now())->where('is_running', Status::YES);
        }
        $crons = $crons->get();
        foreach ($crons as $cron) {
            $cronLog              = new CronJobLog();
            $cronLog->cron_job_id = $cron->id;
            $cronLog->start_at    = now();
            if ($cron->is_default) {
                $controller = new $cron->action[0];
                try {
                    $method = $cron->action[1];
                    $controller->$method();
                } catch (\Exception $e) {
                    $cronLog->error = $e->getMessage();
                }
            } else {
                try {
                    CurlRequest::curlContent($cron->url);
                } catch (\Exception $e) {
                    $cronLog->error = $e->getMessage();
                }
            }
            $cron->last_run = now();
            $cron->next_run = now()->addSeconds($cron->schedule->interval);
            $cron->save();

            $cronLog->end_at = $cron->last_run;

            $startTime         = Carbon::parse($cronLog->start_at);
            $endTime           = Carbon::parse($cronLog->end_at);
            $diffInSeconds     = $startTime->diffInSeconds($endTime);
            $cronLog->duration = $diffInSeconds;
            $cronLog->save();
        }

        if (request()->target == 'all') {
            $notify[] = ['success', 'Cron executed successfully'];
            return back()->withNotify($notify);
        }

        if (request()->alias) {
            $notify[] = ['success', keyToTitle(request()->alias) . ' executed successfully'];
            return back()->withNotify($notify);
        }
    }

    public function cryptoPrice()
    {

        try {
            $general      = gs();
            $url     = 'https://pro-api.coinmarketcap.com/v1/cryptocurrency/quotes/latest';
            $currencies = CryptoCurrency::active()->get();
            $parameters = [
                'symbol' => $currencies->implode('symbol', ','),
            ];
            $headers = [
                'Accepts: application/json',
                'X-CMC_PRO_API_KEY: ' . @$general->coinmarketcap_api_key
            ];
            $qs      = http_build_query($parameters);
            $request = "{$url}?{$qs}";
            $curl    = curl_init();
            curl_setopt_array($curl, array(
                CURLOPT_URL            => $request,
                CURLOPT_HTTPHEADER     => $headers,
                CURLOPT_RETURNTRANSFER => 1
            ));

            $response = curl_exec($curl);
            curl_close($curl);
            $data = json_decode($response);

            if (!@$data->data) {
                $general->cron_error_message = @$data->status->error_message;
                $general->save();
                throw new Exception(@$data->status->error_message);
            } else {
                $general->cron_error_message = null;
                $general->last_cron          = Carbon::now();
                $general->save();
            }
            $rates      = $data->data;
            foreach ($currencies as $currency) {
                $curSym = $currency->symbol;
                $rate = @$rates->$curSym;
                if (!$rate) {
                    continue;
                }
                $currency->price              = @$rate->quote->USD->price;
                $currency->one_hour           = @$rate->quote->USD->percent_change_1h;
                $currency->twenty_four        = @$rate->quote->USD->percent_change_24h;
                $currency->seven_day          = @$rate->quote->USD->percent_change_7d;
                $currency->market_cap         = @$rate->quote->USD->market_cap;
                $currency->volume_24h         = @$rate->quote->USD->volume_24h;
                $currency->crypto_rank        = @$rate->cmc_rank;
                $currency->circulating_supply = @$rate->circulating_supply ?? 0;
                $currency->save();
            }
        } catch (Exception $ex) {
            throw new Exception($ex->getMessage());
        }
    }

    public function trade()
    {

        try {
            $general = gs();
            $tradeLogs = TradeLog::where('result', Status::TRADE_PENDING)
                ->where('status', Status::TRADE_RUNNING)
                ->where('in_time', '<', Carbon::now())
                ->get();

            foreach ($tradeLogs as $tradeLog) {
                $cryptoRate = getCoinRate($tradeLog->crypto->symbol);
                $user       = $tradeLog->user;
                if (!$cryptoRate || !$user) {
                    continue;
                }

                if ($tradeLog->high_low == Status::TRADE_HIGH) {
                    if ($tradeLog->price_was < $cryptoRate) {
                        $tradeAmountWithProfit = $tradeLog->amount + (($tradeLog->amount / 100) * $general->trade_profit);
                        $user->balance += $tradeAmountWithProfit;
                        $user->save();

                        $details        = 'Trade ' . $tradeLog->crypto->name . ' ' . "WIN";
                        $this->transactions($user, $tradeAmountWithProfit, $details, remark: 'trade_win');
                        $tradeLog->result = Status::TRADE_WIN;
                    } else if ($tradeLog->price_was > $cryptoRate) {
                        $tradeLog->result = Status::TRADE_LOSE;
                    } else {
                        $user->balance += $tradeLog->amount;
                        $user->save();

                        $tradeLogAmount = $tradeLog->amount;
                        $details        = 'Trade ' . $tradeLog->crypto->name . ' ' .  "Refund";
                        $this->transactions($user, $tradeLogAmount, $details, remark: 'trade_refund');
                        $tradeLog->result = Status::TRADE_DRAW;
                    }
                } elseif ($tradeLog->high_low == Status::TRADE_LOW) {
                    if ($tradeLog->price_was > $cryptoRate) {
                        $tradeAmountWithProfit  = $tradeLog->amount + (($tradeLog->amount / 100) * $general->trade_profit);
                        $user->balance         += $tradeAmountWithProfit;
                        $user->save();

                        $details = 'Trade ' . $tradeLog->crypto->name . ' ' . "WIN";
                        $this->transactions($user, $tradeAmountWithProfit, $details, remark: 'trade_win');
                        $tradeLog->result = Status::TRADE_WIN;
                    } else if ($tradeLog->price_was < $cryptoRate) {
                        $tradeLog->result = Status::TRADE_LOSE;
                    } else {
                        $user->balance += $tradeLog->amount;
                        $user->save();

                        $tradeLogAmount = $tradeLog->amount;
                        $details        = 'Trade ' . $tradeLog->crypto->name . ' ' .  "Refund";
                        $this->transactions($user, $tradeLogAmount, $details,  remark: 'trade_refund');
                        $tradeLog->result = Status::TRADE_DRAW;
                    }
                }
                $tradeLog->status = Status::TRADE_COMPLETED;
                $tradeLog->save();
            }
            $general->last_cron = Carbon::now();
            $general->save();
        } catch (Exception $ex) {
            throw new Exception(($ex->getMessage()));
        }
    }

    public function practiceCron()
    {
        try {
            $general = gs();
            $tradeLogs = PracticeLog::where('result', Status::TRADE_PENDING)
                ->where('in_time', '<', Carbon::now())
                ->where('status', Status::TRADE_RUNNING)
                ->get();

            foreach ($tradeLogs as $tradeLog) {
                $cryptoRate = getCoinRate($tradeLog->crypto->symbol);
                $user       = $tradeLog->user;

                if (!$cryptoRate || !$user) {
                    continue;
                }
                if ($tradeLog->high_low == Status::TRADE_HIGH) {
                    if ($tradeLog->price_was < $cryptoRate) {
                        $user->demo_balance += $tradeLog->amount + (($tradeLog->amount / 100) * $general->trade_profit);
                        $user->save();
                        $tradeLog->result = Status::TRADE_WIN;
                    } else if ($tradeLog->price_was > $cryptoRate) {
                        $tradeLog->result = Status::TRADE_LOSE;
                    } else {
                        $user->demo_balance += $tradeLog->amount;
                        $user->save();

                        $tradeLog->result = Status::TRADE_DRAW;
                    }
                } elseif ($tradeLog->high_low == Status::TRADE_LOW) {
                    if ($tradeLog->price_was > $cryptoRate) {
                        $user->demo_balance += $tradeLog->amount + (($tradeLog->amount / 100) * $general->trade_profit);
                        $user->save();
                        $tradeLog->result = Status::TRADE_WIN;
                    } else if ($tradeLog->price_was < $cryptoRate) {
                        $tradeLog->result = Status::TRADE_LOSE;
                    } else {
                        $user->demo_balance += $tradeLog->amount;
                        $user->save();

                        $tradeLog->result = Status::TRADE_DRAW;
                    }
                }
                $tradeLog->status = Status::TRADE_COMPLETED;
                $tradeLog->save();
            }
            $general->last_cron = Carbon::now();
            $general->save();
        } catch (Exception $ex) {
            throw new Exception($ex->getMessage());
        }
    }

    public function transactions($user, $gameLogAmount, $details, $remark = '')
    {
        $transaction               = new Transaction();
        $transaction->user_id      = $user->id;
        $transaction->amount       = $gameLogAmount;
        $transaction->post_balance = $user->balance;
        $transaction->trx_type     = "+";
        $transaction->details      = $details;
        $transaction->remark       = $remark;
        $transaction->trx          = getTrx();
        $transaction->save();
    }
}
